@@ -4,9 +4,15 @@ import pprint
 import sys
 from typing import List
 
+from jinja2 import Environment, FileSystemLoader
+
 from .template import Template
 from .utils import get_parts
 
+log = logging.getLogger(__name__)
+
+dir = os.path.dirname(__file__)
+env = Environment(loader=FileSystemLoader(f"{dir}/templates"))
 
 def parse_params(args):
     args = " ".join(args)
@@ -33,7 +39,7 @@ def parse_params(args):
                 prev_elem = None
                 continue
             else:
-                print(f"don't know waht to do with {elem}")
+                log.error(f"don't know what to do with {elem}")
 
         prev_elem = elem
 
@@ -71,16 +77,19 @@ def cmd(args: List[str]):
                 case 'run':
                     t = Template.from_file(filename, params)
                     t.run()
-                    print(t)
+                    cmd_template = env.get_template("run.jinja")
+                    print(cmd_template.render(template=t))
 
                 case 'render':
                     t, v = Template.render_from_file(filename, params)
-                    show_template(filename, params, t, v)
+                    cmd_template = env.get_template("render.jinja")
+                    print(cmd_template.render(t=t, v=pprint.pformat(v), filename=filename, params=params))
 
                 case 'sample':
                     t = Template.from_file(filename, params)
                     t.generate()
-                    print(t)
+                    cmd_template = env.get_template("sample.jinja")
+                    print(cmd_template.render(template=t))
 
                 case 'sample-all':
                     for root, _, filenames in os.walk(filename):
@@ -94,50 +103,21 @@ def cmd(args: List[str]):
                                 except Exception as e:
                                     print(filepath, e)
 
-                case _:
-                    Exception(f"Unrecognised command {cmd}")
+                case _ as c:
+                    show_help(msg=f"Unrecognised command [{cmd}]. Expected one of render, sample, run or sample-all.")
 
-        case _:
-            print("Unrecognised args [{cmd_args}]")
-            show_help()
-
-def show_help():
-    s = """\
-faux-data - a fake data generator.
-
-Usage:
-  faux [command]
-
-Available Commands:
-  render filename.yaml [params]    render a template
-  sample filename.yaml [params]    generate a sample dataset for a template
-  run filename.yaml [params]       run a template loading data to the specified targets
-
-Flags:
-  --debug    enable debug logging
-
-  extra flags are passed to the template to override variables
-  e.g faux render templates/mytemplate.yaml --myvar=foo
-"""
-    print(s)
-
-def show_template(filename, params, t, v):
-    s = f"""\
-Filename: {filename}
-Input params: {params}
-===================== Resolved Parameters ======================
-{pprint.pformat(v)}
-====================== Rendered Template =======================
-{t}
-================================================================"""
-    print(s)
+        case _ as args:
+            show_help(msg=f"Unrecognised arguments {args}. Expected faux <command> <arg> [--flag ...].")
 
+def show_help(msg: str = None):
+    cmd_template = env.get_template("help.jinja")
+    print(cmd_template.render(msg=msg))
 
 
 def set_debug(params: dict) -> None:
     if params.get("debug"):
         logging.basicConfig(level="DEBUG")
-        logging.debug(f"Parsed params {params} from args {sys.argv}")
+        log.debug(f"Parsed params {params} from args {sys.argv}")
     else:
         logging.basicConfig(level="INFO")
 
