@@ -20,3 +20,13 @@ def get_parts(val: str):
             return g[1]
 
     return [first_non_empty(group) for group in groups]
+
+
+def split_gcs_path(path: str):
+    """Splits a path into bucket and the object path parts."""
+
+    pattern = "(?:gs://)?(?P<bucket>[^/]+)/(?P<obj>.+)"
+    path = re.match(pattern, path)
+    if not path:
+        raise Exception(f"path [{path}] is invalid")
+    return path
\ No newline at end of file
